@@ -298,6 +298,15 @@ class OperatingMode(IntEnum):
     ECO = 100
 
 
+@unique
+class OperatingState(IntEnum):
+    """Operating state."""
+
+    IDLE = 0
+    HEATING = 1
+    COOLING = 2
+
+
 @unique
 class SensorType(IntEnum):
     """Sensor type."""
